@@ -8,11 +8,18 @@ menu_items = (
         buttons=(
             PluginMenuButton(
                 "plugins:netbox_dns:zone_add",
-                "Zones Add",
+                "Add",
                 "mdi mdi-plus-thick",
                 ButtonColorChoices.GREEN,
                 permissions=["netbox_dns.add_zone"],
             ),
+            PluginMenuButton(
+                "plugins:netbox_dns:zone_import",
+                "Import",
+                "mdi mdi-upload",
+                ButtonColorChoices.CYAN,
+                permissions=["netbox_dns.add_zone"],
+            ),
         ),
     ),
     PluginMenuItem(
@@ -21,11 +28,18 @@ menu_items = (
         buttons=(
             PluginMenuButton(
                 "plugins:netbox_dns:nameserver_add",
-                "Nameserver Add",
+                "Add",
                 "mdi mdi-plus-thick",
                 ButtonColorChoices.GREEN,
                 permissions=["netbox_dns.add_nameserver"],
             ),
+            PluginMenuButton(
+                "plugins:netbox_dns:nameserver_import",
+                "Import",
+                "mdi mdi-upload",
+                ButtonColorChoices.CYAN,
+                permissions=["netbox_dns.add_nameserver"],
+            ),
         ),
     ),
     PluginMenuItem(
@@ -34,11 +48,18 @@ menu_items = (
         buttons=(
             PluginMenuButton(
                 "plugins:netbox_dns:record_add",
-                "Record Add",
+                "Add",
                 "mdi mdi-plus-thick",
                 ButtonColorChoices.GREEN,
                 permissions=["netbox_dns.add_record"],
             ),
+            PluginMenuButton(
+                "plugins:netbox_dns:record_import",
+                "Import",
+                "mdi mdi-upload",
+                ButtonColorChoices.CYAN,
+                permissions=["netbox_dns.add_record"],
+            ),
         ),
     ),
 )
