@@ -1,5 +1,5 @@
 import django_tables2 as tables
-from utilities.tables import BaseTable, ChoiceFieldColumn, ToggleColumn
+from utilities.tables import BaseTable, ChoiceFieldColumn, ToggleColumn, TagColumn
 from .models import NameServer, Record, Zone
 
 
@@ -9,6 +9,9 @@ class ZoneTable(BaseTable):
     pk = ToggleColumn()
     name = tables.LinkColumn()
     status = ChoiceFieldColumn()
+    tags = TagColumn(
+        url_name="plugins:netbox_dns:zone_list",
+    )
 
     class Meta(BaseTable.Meta):
         model = Zone
@@ -16,6 +19,7 @@ class ZoneTable(BaseTable):
             "pk",
             "name",
             "status",
+            "tags",
         )
 
 
@@ -24,12 +28,16 @@ class NameServerTable(BaseTable):
 
     pk = ToggleColumn()
     name = tables.LinkColumn()
+    tags = TagColumn(
+        url_name="plugins:netbox_dns:nameserver_list",
+    )
 
     class Meta(BaseTable.Meta):
         model = NameServer
         fields = (
             "pk",
             "name",
+            "tags",
         )
 
 
@@ -40,6 +48,9 @@ class RecordTable(BaseTable):
     zone = tables.LinkColumn()
     type = tables.LinkColumn()
     name = tables.LinkColumn()
+    tags = TagColumn(
+        url_name="plugins:netbox_dns:record_list",
+    )
 
     class Meta(BaseTable.Meta):
         model = Record
@@ -49,4 +60,5 @@ class RecordTable(BaseTable):
             "type",
             "name",
             "value",
+            "tags",
         )
